instrumenttools.EnglishHorn
===========================

.. abjad-lineage:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn

.. autoclass:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__repr__
   :noindex:
